@@ -16,9 +16,9 @@ agents = create_agent
 thermometer = Thermometer
 size = lambda: 20
 
-environment = environment_factory()
+environment = environment_factory(regeneration_factor=0.1)
 
 stop_condition = lambda: StepLimitStopCondition(90)
 
 address_provider = address.SequenceAddressProvider
-stats = CsvStatistics
\ No newline at end of file
+stats = lambda: CsvStatistics(interval=100)
\ No newline at end of file
